import { useContext } from "react";
import { useQuery } from "react-query";
import { store } from "../store";

export interface Channel {
    userID: string,
    name: string
}

export function useChannels(): Array<Channel> {
	const { state } = useContext(store);

	const { data } = useQuery<Array<Channel>>(`channels`, () => {
			const queryUrl = new URL(`${state.apiBaseUrl}/channels`);

			return fetch(queryUrl.toString()).then((response) => {
					if (response.ok) {
							return response;
					}

					throw Error(response.statusText);
			}).then(response => response.json())
					.then((data: { channels: Array<Channel> }) => {
							// Assuming each Channel object has a 'name' property
							// Sort the channels alphabetically by 'name'
							return data.channels.sort((a, b) => a.name.localeCompare(b.name));
					});
	}, { refetchOnWindowFocus: false, refetchOnReconnect: false });

	// Return the sorted data or an empty array if data is undefined
	return data ?? [];
}
