import { StrictMode } from "react";
import { useContext } from "react";
import { createRoot } from "react-dom/client";
import { QueryClientProvider } from "react-query";
import { Page } from "./components/Page";
import { StateProvider, store } from "./store";
import { createTheme } from "@mui/material";
import { ThemeProvider } from "@mui/material/styles";
import i18n from "i18next";
import { initReactI18next } from "react-i18next";
import LanguageDetector from "i18next-browser-languagedetector";

const resources = {
  en: {
    translation: {
			load: "load",
      channel: "channel or id:123",
      username: "username or id:123",
			emote: "Show Emotes",
			name: "Show Name",
			timestamp: "Show Timestamp",
			chatmode: "Twitch Chat Mode",
			newmsgbottom: "Newest messages at the bottom",
    },
  },
  es: {
    translation: {
			load: "cargar",
      channel: "canal o id:123",
      username: "usuario o id:123",
			emote: "Mostrar Emotes",
			name: "Mostrar Nombre",
			timestamp: "Mostrar Timestamp",
			chatmode: "Modo de chat de Twitch",
    },
  },
};

i18n
  .use(LanguageDetector)
  .use(initReactI18next)
  .init({
    resources,
    fallbackLng: "en",
    supportedLngs: ["es", "en"],
    interpolation: {
      escapeValue: false,
    },
    detection: {
      order: ["querystring", "navigator", "htmlTag"],
    },
  });

export default i18n;

const pageTheme = createTheme({
  palette: {
    mode: "dark",
  },
});

function App() {
  const { state } = useContext(store);

  return (
    <QueryClientProvider client={state.queryClient}>
      <Page />
    </QueryClientProvider>
  );
}

const container = document.getElementById("root") as Element;
const root = createRoot(container);

root.render(
  <StrictMode>
    <StateProvider>
      <ThemeProvider theme={pageTheme}>
        <App />
      </ThemeProvider>
    </StateProvider>
  </StrictMode>
);
